@@ -42,7 +42,13 @@ class intToVec:
 
 
 class VecSS:
-    def __init__(self, f="small_cDNA_Sequences_pbmc_1k_v2_S1_L002_R2_001.fastq", length=10000, encoding="one-hot-encoding",bits=8):
+    def __init__(
+        self,
+        f="small_cDNA_Sequences_pbmc_1k_v2_S1_L002_R2_001.fastq",
+        length=10000,
+        encoding="one-hot-encoding",
+        bits=8,
+    ):
         self.encoding = encoding
         self.bits = bits
         self.__file = f
@@ -51,7 +57,7 @@ class VecSS:
         self.embeddings = self.embed(self.s)
         self.samples = 2
 
-#        self.enc = encoder.Encoder(bits=self.bits, encoding=self.encoding)
+    #        self.enc = encoder.Encoder(bits=self.bits, encoding=self.encoding)
 
     def readq(self):
         R = reader.Reader()
